@@ -5,4 +5,7 @@
 #'
 #' @docType package
 #' @name cdata
-NULL
\ No newline at end of file
+NULL
+
+# make sure dot doesn't look like an unbound ref
+. <- NULL
